//#define NU32_STANDALONE  // uncomment if program is standalone, not bootloaded
#include "NU32.h"          // plib.h, config bits, constants, funcs for startup and UART

#define PERIOD 1024        // this is PR2 + 1
#define MAXVOLTAGE 3.3     // in case another voltage is used

int getUserPulseWidth(void) {
  char msg[100];
  float f;
  int hightime;

  sprintf(msg,"Enter the desired voltage, from 0 to %3.1f (volts): ",MAXVOLTAGE);
  NU32_WriteUART1(msg);
  NU32_ReadUART1(msg,10);
  sscanf(msg,"%f",&f);
  if (f>MAXVOLTAGE) f = MAXVOLTAGE;
  if (f<0.0) f = 0.0;
  sprintf(msg,"\r\nSending %5.3f volts.\r\n",f);
  NU32_WriteUART1(msg);
  hightime = (int) (0.5 + PERIOD*f/MAXVOLTAGE);  // convert volts to counts
  return(hightime);
}

int main(void) {
  NU32_Startup(); // cache on, min flash wait, interrupts on, LED/button init, UART init

  PR2 = PERIOD-1; // Timer2 is the base for OC5, PR2 defines PWM frequency
  TMR2 = 0;
  T2CON = 1<<15;  // turn Timer2 on, all defaults fine
  // below, only OC_ON is needed for config, others are defaults.
  // initial pulse width is 0 counts (0 volts out)
  OpenOC5(OC_ON | OC_PWM_FAULT_PIN_DISABLE | OC_TIMER2_SRC | OC_TIMER_MODE16, 0, 0);
  while (1) {
    OC5RS = getUserPulseWidth();
  }
  return 0;
}
